Resources management — Kivy v1.0.1-dev documentation

# Resources management

Resource management can be a pain if you have multiple path and project. We are offering you 2 functions for searching specific resources across a list of paths.

`kivy.resources.` `resource_find`(filename)

  Search a resource in list of paths. Use resource_add_path to add a custom path to search.

`kivy.resources.` `resource_add_path`(path)

  Add a custom path to search in